@@ -8,6 +8,7 @@ class BaseCanvas():
     FONT_SIZE = 12
     BOLD = False
     ITALIC = False
+    SHOULD_FILL = True
 
     def __init__(self):
         pygame.init()
@@ -67,7 +68,8 @@ class BaseCanvas():
 
     def loop(self):
         while self._continue_flag:
-            self.canvas.fill(self.BACKGROUND_COLOR)
+            if self.SHOULD_FILL:
+                self.canvas.fill(self.BACKGROUND_COLOR)
             self.loop_hook()
             pygame.display.update()
             self._handle_events()
